==> SCENARIclient_3.5.005_lin.tgz: bin/scChain/defaults/preferences/confGeneral.js <==



pref("toolkit.defaultChromeURI", "chrome://scenaricms/content/deskwsp/deskwsp.xul");

pref("network.protocol-handler.warn-external-default", false);

pref("browser.download.useDownloadDir", false);
pref("browser.download.manager.focusWhenStarting", false);
pref("browser.download.manager.showWhenStarting", false);
pref("browser.download.manager.useWindow", false);







pref("editor.singleLine.pasteNewlines",     1);

pref("general.useragent.locale", "fr-FR");

pref("editor.custom_direction", "none");
pref("editor.custom_language", "");
pref("editor.custom_charset", "UTF-8");
pref("editor.use_custom_colors", false);


pref("dom.max_chrome_script_run_time", 30);
pref("dom.max_script_run_time", 30);


pref("layout.spellcheckDefault", 2);
pref("extensions.spellcheck.inline.max-misspellings", 500);
pref("spellchecker.dictionary", "fr-FR");


pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul?type=themes");
pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul?type=extensions");
pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes");
pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
pref("extensions.update.enabled", false);
pref("extensions.update.interval", 86400);
pref("extensions.dss.enabled", false);
pref("extensions.dss.switchPending", false);
pref("extensions.ignoreMTimeChanges", false);
pref("extensions.logging.enabled", false);
pref("general.skins.selectedSkin", "classic/1.0");
pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.checkCompatibility", false);


pref("scenari.extensions.showMigrateWindow", false);


pref("scenari.version.minor.length", 1);//Permet de spcifier la taille de la version mineure de communication. 0 => que la vMineur de comm correspond  tout le paramtre @mineur

pref("app.update.silent", true);
pref("app.update.auto", false);


pref("network.protocol-handler.expose.mailto", false);
pref("network.protocol-handler.expose.mailbox", false);
pref("network.protocol-handler.expose.http", false);
pref("network.protocol-handler.expose.https", false);
pref("network.protocol-handler.warn-external.http", false);
pref("network.protocol-handler.warn-external.https", false);

pref("scenari.install.xpi.mode", "inProfile");//[inProfile | inApplication | forbidden]
pref("app.name","SCENARIclient");
pref("app.version.developmentStage","");
pref("app.version.buildId","2008061115");
pref("app.version","3.5.005");
pref("app.extensions.version","3.5.005");

pref("scenari.reposCmsServerName", "scServer");
pref("scenari.jvm.xms", "256M");
pref("scenari.jvm.xmx", "256M");

==> SCENARIclient_3.5.100_lin.tgz: bin/scChain/defaults/preferences/confGeneral.js <==



pref("toolkit.defaultChromeURI", "chrome://scenaricms/content/deskwsp/deskwsp.xul");

pref("network.protocol-handler.warn-external-default", false);

pref("browser.download.useDownloadDir", false);
pref("browser.download.manager.focusWhenStarting", false);
pref("browser.download.manager.showWhenStarting", false);
pref("browser.download.manager.useWindow", false);







pref("editor.singleLine.pasteNewlines",     1);

pref("general.useragent.locale", "fr-FR");

pref("editor.custom_direction", "none");
pref("editor.custom_language", "");
pref("editor.custom_charset", "UTF-8");
pref("editor.use_custom_colors", false);


pref("dom.max_chrome_script_run_time", 30);
pref("dom.max_script_run_time", 30);


pref("layout.spellcheckDefault", 2);
pref("extensions.spellcheck.inline.max-misspellings", 500);
pref("spellchecker.dictionary", "fr-FR");


pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul?type=themes");
pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul?type=extensions");
pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes");
pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
pref("extensions.update.enabled", false);
pref("extensions.update.interval", 86400);
pref("extensions.dss.enabled", false);
pref("extensions.dss.switchPending", false);
pref("extensions.ignoreMTimeChanges", false);
pref("extensions.logging.enabled", false);
pref("general.skins.selectedSkin", "classic/1.0");
pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
pref("extensions.checkCompatibility", false);


pref("scenari.extensions.showMigrateWindow", false);


pref("scenari.version.minor.length", 1);//Permet de spcifier la taille de la version mineure de communication. 0 => que la vMineur de comm correspond  tout le paramtre @mineur

pref("app.update.silent", true);
pref("app.update.auto", false);


pref("network.protocol-handler.expose.mailto", false);
pref("network.protocol-handler.expose.mailbox", false);
pref("network.protocol-handler.expose.http", false);
pref("network.protocol-handler.expose.https", false);
pref("network.protocol-handler.warn-external.http", false);
pref("network.protocol-handler.warn-external.https", false);

pref("scenari.install.xpi.mode", "inProfile");//[inProfile | inApplication | forbidden]
pref("app.name","SCENARIclient");
pref("app.version.developmentStage","final");
pref("app.version.buildId","2008072317");
pref("app.version","3.5.100");
pref("app.extensions.version","3.5.100");

pref("scenari.reposCmsServerName", "scServer");
pref("scenari.jvm.xms", "256M");
pref("scenari.jvm.xmx", "256M");
